@@ -1,4 +1,5 @@
 import enum
+import re
 from dataclasses import dataclass
 from typing import Dict, Optional, Tuple
 
@@ -203,7 +204,10 @@ class _ImageNameParser:
     def has_tag(self, image: str) -> bool:
         prefix = "image:"
         if image.startswith(prefix):
-            image = image[len(prefix) :]
+            url = URL(image)
+            image = url.path
+            if image.startswith("/"):
+                image = image[1:]
         _, tag = self._split_image_name(image)
         return bool(tag)
 
@@ -315,8 +319,34 @@ class _ImageNameParser:
             name, tag = image.rsplit(":", 1)
         else:
             raise ValueError("too many tags")
-        if tag and (":" in tag or "/" in tag):
-            raise ValueError("invalid tag")
+        if "/" in name:
+            _, name_no_repo = name.split("/", 1)
+        else:
+            name_no_repo = name
+        if not name_no_repo:
+            raise ValueError("no image name specified")
+        if not re.fullmatch(
+            r"(?:[a-z0-9]+(?:[._-][a-z0-9]+)*/)*[a-z0-9]+(?:[._-][a-z0-9]+)*",
+            name_no_repo,
+        ):
+            raise ValueError(
+                "invalid image name. Docker specifies it to be the following:\n"
+                "Name components may contain lowercase letters, digits and "
+                "separators. A separator is defined as a period, one or two "
+                "underscores, or one or more dashes. A name component may not "
+                "start or end with a separator."
+            )
+        if tag:
+            if len(tag) > 128:
+                raise ValueError("tag is to long")
+            if not re.fullmatch(r"[a-zA-Z0-9_]+[a-zA-Z0-9_.-]*", tag):
+                raise ValueError(
+                    "invalid tag. Docker specifies it to be the following:\n"
+                    "A tag name must be valid ASCII and may contain lowercase "
+                    "and uppercase letters, digits, underscores, periods and "
+                    "dashes. A tag name may not start with a period or a dash "
+                    "and may contain a maximum of 128 characters."
+                )
         return name, tag
 
 
