@@ -43,6 +43,15 @@ class TestImageParser:
             "another": URL("https://example.org"),
         },
     )
+    parser_with_org = _ImageNameParser(
+        default_user="alice",
+        default_cluster="default",
+        default_org="test-org",
+        registry_urls={
+            "default": URL("https://reg.neu.ro"),
+            "another": URL("https://example.org"),
+        },
+    )
 
     @pytest.mark.parametrize(
         "image",
@@ -205,12 +214,10 @@ class TestImageParser:
         ):
             self.parser.parse_as_local_image(image)
 
-    def test_parse_as_local_image_with_other_scheme_ok(self) -> None:
+    def test_parse_as_local_image_with_other_scheme_fail(self) -> None:
         image = "http://ubuntu"
-        parsed = self.parser.parse_as_local_image(image)
-        # instead of parser, the docker client will fail
-        assert parsed == LocalImage(name="http://ubuntu", tag="latest")
-        assert self.parser.parse_as_local_image(str(parsed)) == parsed
+        with pytest.raises(ValueError, match="invalid image name"):
+            self.parser.parse_as_local_image(image)
 
     def test_parse_as_local_image_no_tag(self) -> None:
         image = "ubuntu"
@@ -225,9 +232,8 @@ class TestImageParser:
 
     def test_parse_as_local_image_special_chars(self) -> None:
         image = "image#%2d?ß:tag#%2d?ß"
-        parsed = self.parser.parse_as_local_image(image)
-        assert parsed == LocalImage(name="image#%2d?ß", tag="tag#%2d?ß")
-        assert self.parser.parse_as_local_image(str(parsed)) == parsed
+        with pytest.raises(ValueError):
+            self.parser.parse_as_local_image(image)
 
     def test_parse_as_local_image_2_tag_fail(self) -> None:
         image = "ubuntu:v10.04:LTS"
@@ -319,20 +325,45 @@ class TestImageParser:
         ):
             self.parser.parse_as_neuro_image(image)
 
-    def test_parse_as_neuro_image_with_org(
-        self,
-    ) -> None:
-        image = "image://another/test-org/bob/ubuntu:v10.04"
-        parser = _ImageNameParser(
-            default_user="alice",
-            default_cluster="default",
-            default_org="test-org",
-            registry_urls={
-                "default": URL("https://reg.neu.ro"),
-                "another": URL("https://example.org"),
-            },
+    def test_parse_as_neuro_image_with_default_org_no_org(self) -> None:
+        image = "image://another/bob/ubuntu:v10.04"
+        parsed = self.parser_with_org.parse_as_neuro_image(image)
+        assert parsed == RemoteImage.new_neuro_image(
+            name="ubuntu",
+            tag="v10.04",
+            owner="bob",
+            cluster_name="another",
+            registry="example.org",
+            org_name=None,
         )
-        parsed = parser.parse_as_neuro_image(image)
+
+    def test_parse_as_neuro_image_with_default_org_no_cluster_no_org(self) -> None:
+        image = "image:/bob/ubuntu:v10.04"
+        parsed = self.parser_with_org.parse_as_neuro_image(image)
+        assert parsed == RemoteImage.new_neuro_image(
+            name="ubuntu",
+            tag="v10.04",
+            owner="bob",
+            cluster_name="default",
+            registry="reg.neu.ro",
+            org_name="test-org",
+        )
+
+    def test_parse_as_neuro_image_with_default_org_no_cluster_no_user(self) -> None:
+        image = "image:ubuntu:v10.04"
+        parsed = self.parser_with_org.parse_as_neuro_image(image)
+        assert parsed == RemoteImage.new_neuro_image(
+            name="ubuntu",
+            tag="v10.04",
+            owner="alice",
+            cluster_name="default",
+            registry="reg.neu.ro",
+            org_name="test-org",
+        )
+
+    def test_parse_as_neuro_image_with_default_org_same_org(self) -> None:
+        image = "image://another/test-org/bob/ubuntu:v10.04"
+        parsed = self.parser_with_org.parse_as_neuro_image(image)
         assert parsed == RemoteImage.new_neuro_image(
             name="ubuntu",
             tag="v10.04",
@@ -342,6 +373,32 @@ class TestImageParser:
             org_name="test-org",
         )
 
+    # XXX: Ambigious URI
+    def test_parse_as_neuro_image_with_default_org_other_org(self) -> None:
+        image = "image://another/org/bob/ubuntu:v10.04"
+        parsed = self.parser_with_org.parse_as_neuro_image(image)
+        assert parsed == RemoteImage.new_neuro_image(
+            name="bob/ubuntu",
+            tag="v10.04",
+            owner="org",
+            cluster_name="another",
+            registry="example.org",
+            org_name=None,
+        )
+
+    # XXX: Ambigious URI
+    def test_parse_as_neuro_image_without_default_org_with_org(self) -> None:
+        image = "image://another/test-org/bob/ubuntu:v10.04"
+        parsed = self.parser.parse_as_neuro_image(image)
+        assert parsed == RemoteImage.new_neuro_image(
+            name="bob/ubuntu",
+            tag="v10.04",
+            owner="test-org",
+            cluster_name="another",
+            registry="example.org",
+            org_name=None,
+        )
+
     def test_parse_as_neuro_image_with_scheme_with_cluster_with_user_with_tag(
         self,
     ) -> None:
@@ -671,16 +728,8 @@ class TestImageParser:
 
     def test_parse_as_neuro_image_with_scheme_special_chars(self) -> None:
         image = "image://another/bob/ubuntu%23%252d%3F%C3%9F:v10.04%23%252d%3F%C3%9F"
-        parsed = self.parser.parse_as_neuro_image(image)
-        assert parsed == RemoteImage.new_neuro_image(
-            name="ubuntu#%2d?ß",
-            tag="v10.04#%2d?ß",
-            owner="bob",
-            cluster_name="another",
-            registry="example.org",
-            org_name=None,
-        )
-        assert self.parser.parse_as_neuro_image(str(parsed)) == parsed
+        with pytest.raises(ValueError, match="invalid image name"):
+            self.parser.parse_as_neuro_image(image)
 
     def test_parse_as_neuro_image_no_scheme_no_slash_no_tag_fail(self) -> None:
         image = "ubuntu"
@@ -722,18 +771,10 @@ class TestImageParser:
         assert str(image) == "image://default/user/image:tag"
 
     def test_parse_as_neuro_image_with_registry_prefix_special_chars(self) -> None:
-        image = self.parser.parse_as_neuro_image(
-            "reg.neu.ro/user/image%23%252d%3F%C3%9F:tag%23%252d%3F%C3%9F"
-        )
-        assert image == RemoteImage.new_neuro_image(
-            name="image#%2d?ß",
-            tag="tag#%2d?ß",
-            owner="user",
-            cluster_name="default",
-            registry="reg.neu.ro",
-            org_name=None,
-        )
-        assert self.parser.parse_as_neuro_image(str(image)) == image
+        with pytest.raises(ValueError, match="invalid image name"):
+            self.parser.parse_as_neuro_image(
+                "reg.neu.ro/user/image%23%252d%3F%C3%9F:tag%23%252d%3F%C3%9F"
+            )
 
     def test_parse_as_neuro_image_no_scheme_3_slash_with_tag_fail(self) -> None:
         image = "something/docker.io/library/ubuntu:v10.04"
@@ -799,16 +840,7 @@ class TestImageParser:
 
     def test_convert_to_neuro_image_with_defualt_org(self) -> None:
         local_image = LocalImage(name="ubuntu", tag="latest")
-        parser = _ImageNameParser(
-            default_user="alice",
-            default_cluster="default",
-            default_org="test-org",
-            registry_urls={
-                "default": URL("https://reg.neu.ro"),
-                "another": URL("https://example.org"),
-            },
-        )
-        neuro_image = parser.convert_to_neuro_image(local_image)
+        neuro_image = self.parser_with_org.convert_to_neuro_image(local_image)
         assert neuro_image == RemoteImage.new_neuro_image(
             name="ubuntu",
             tag="latest",
